@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2005 IBM Corporation and others.
+ * Copyright (c) 2003, 2006 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -16,6 +16,7 @@ import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.core.runtime.IPath;
 
 import org.eclipse.cdt.managedbuilder.makegen.IManagedDependencyGenerator;
+import org.eclipse.cdt.managedbuilder.makegen.IManagedDependencyGeneratorType;
 
 /**
  * This interface represents a utility of some sort that is used in the build process.
@@ -547,9 +548,9 @@ public interface ITool extends IBuildObject, IHoldsOptions {
 	 * when the project is built.
 	 *
 	 * @param sourceExt  source file extension
-	 * @return IManagedDependencyGenerator
+	 * @return IManagedDependencyGeneratorType
 	 */
-	public IManagedDependencyGenerator getDependencyGeneratorForExtension(String sourceExt);
+	public IManagedDependencyGeneratorType getDependencyGeneratorForExtension(String sourceExt);
 	
 	/**
 	 * Returns an array of command line arguments that have been specified for
@@ -635,6 +636,17 @@ public interface ITool extends IBuildObject, IHoldsOptions {
 	 * @return boolean
 	 */
 	public boolean buildsFileType(String extension);
+
+	/**
+	 * Return <code>true</code> if the receiver uses files with the
+	 * specified extension as input, else <code>false</code>.  This
+	 * returns true for a superset of the extensions that buildFileType
+	 * returns true for - it includes secondary inputs.
+	 * 
+	 * @param extension file extension of the source
+	 * @return boolean
+	 */
+	public boolean isInputFileType(String extension);
 	
 	/**
 	 * Answers <code>true</code> if the tool considers the file extension to be 
